
# Slot: load_node_list_in_parallel


Whether to load the node list in parallel. When loading in parallel, without node IDs, the nodes may not be loaded in a deterministic order.

URI: [https://w3id.org/neat/ensmallenRunConfig__load_node_list_in_parallel](https://w3id.org/neat/ensmallenRunConfig__load_node_list_in_parallel)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
